@@ -6,9 +6,9 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..1\n"; }
+BEGIN { $| = 1; print "1..2\n"; }
 END {print "not ok 1\n" unless $loaded;}
-use Gimp;
+use Gimp qw( interface=lib :auto );
 $loaded = 1;
 print "ok 1\n";
 
@@ -18,3 +18,7 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
+print SHARPEN == 1 ? "ok 2\n" : "not ok 2\n";
+
+
+
